Enum Class NodeResolutionResult.NpmrcScope

java.lang.Object
java.lang.Enum<NodeResolutionResult.NpmrcScope>
org.openrewrite.javascript.marker.NodeResolutionResult.NpmrcScope
All Implemented Interfaces:
Serializable, Comparable<NodeResolutionResult.NpmrcScope>, Constable
Enclosing class:
NodeResolutionResult

public static enum NodeResolutionResult.NpmrcScope extends Enum<NodeResolutionResult.NpmrcScope>
Represents the scope/source of an npmrc configuration. Listed from lowest to highest priority.
  • Enum Constant Details

  • Method Details

    • values

      public static NodeResolutionResult.NpmrcScope[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static NodeResolutionResult.NpmrcScope valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null