Package org.openrewrite.javascript.marker
@NullMarked
package org.openrewrite.javascript.marker
-
ClassDescriptionNote: this may be used across all languages to represent a keyword as an annotation, and print without the `@`.Contains metadata about a Node.js project, parsed from package.json and package-lock.json.Represents a dependency request as declared in package.json.Represents npm configuration from a specific scope.Represents the scope/source of an npmrc configuration.Represents the package manager used by a Node.js project.Represents a resolved dependency from package-lock.json.