Class DependencyInsight
java.lang.Object
org.openrewrite.Recipe
org.openrewrite.javascript.search.DependencyInsight
- All Implemented Interfaces:
Cloneable
public class DependencyInsight
extends org.openrewrite.Recipe
Find direct and transitive npm dependencies matching a package name pattern.
Results include dependencies that either directly match or transitively include
a matching dependency. Search result markers are placed on the dependency key
in package.json.
-
Nested Class Summary
Nested classes/interfaces inherited from class org.openrewrite.Recipe
org.openrewrite.Recipe.Builder, org.openrewrite.Recipe.DelegatingRecipe -
Field Summary
Fields inherited from class org.openrewrite.Recipe
contributors, examples, PANIC -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class org.openrewrite.Recipe
addDataTable, builder, buildRecipeList, causesAnotherCycle, clone, createRecipeDescriptor, equals, getContributors, getDataTableDescriptors, getDescription, getDescriptor, getDisplayName, getEstimatedEffortPerOccurrence, getExamples, getInstanceName, getJacksonPolymorphicTypeTag, getMaintainers, getName, getRecipeList, getTags, hashCode, maxCycles, noop, onComplete, run, run, run, setContributors, setExamples, validate, validateAll, validateAll, withOptions
-
Constructor Details
-
DependencyInsight
public DependencyInsight()
-
-
Method Details
-
getInstanceNameSuffix
- Overrides:
getInstanceNameSuffixin classorg.openrewrite.Recipe
-
validate
- Overrides:
validatein classorg.openrewrite.Recipe
-
getVisitor
public org.openrewrite.TreeVisitor<?,org.openrewrite.ExecutionContext> getVisitor()- Overrides:
getVisitorin classorg.openrewrite.Recipe
-