All Classes and Interfaces
Class
Description
Auto-detected styles for JavaScript/TypeScript code.
Converts a
bun.lock JSONC string into the npm package-lock.json v3
shape consumed by LockFileParser.Find direct and transitive npm dependencies matching a package name pattern.
A segment in a transitive-dependency override path.
A receiver for JavaScript AST elements that uses the Java RPC framework.
A sender for JavaScript AST elements that uses the Java RPC framework.
Validates that the contents of lists and containers like JLeftPadded respect their generic types.
JSX elements for JavaScript AST.
Represents a JSX tag.
Note: this may be used across all languages to represent a keyword as an annotation, and print without the `@`.
Parses an npm
package-lock.json v3-format string into structured
NodeResolutionResult.ResolvedDependency instances.Regenerate a JavaScript project's lock file by running the package manager
in a temp directory seeded with the package.json and (optionally) the existing
lock file plus config files such as
.npmrc.A dependency match for `UpgradeDependencyVersion`: where it lives + its current version.
Contains metadata about a Node.js project, parsed from package.json and package-lock.json.
Represents a dependency request as declared in package.json.
Represents npm configuration from a specific scope.
Represents the scope/source of an npmrc configuration.
Represents the package manager used by a Node.js project.
Represents a resolved dependency from package-lock.json.
Shared utilities for npm dependency recipes operating on package.json files
and their associated lock files.
Ports
parseDependencyPath and applyOverrideToPackageJson
from dependency-manager.ts.Parser for package.json files that delegates to the TypeScript PackageJsonParser via RPC.
Locates and runs a Node.js package manager CLI (npm, yarn, pnpm, bun).
Converts a
pnpm-lock.yaml into the npm v3 shape consumed by
LockFileParser.Marker containing the resolved Prettier configuration for a source file.
Converts a yarn 2+ (Berry)
yarn.lock (YAML) into the npm v3 shape
consumed by LockFileParser.Converts a yarn 1.x
yarn.lock (custom non-YAML format) into the
npm package-lock.json v3 shape consumed by LockFileParser.