All Classes and Interfaces

Class
Description
 
Auto-detected styles for JavaScript/TypeScript code.
 
 
 
Find direct and transitive npm dependencies matching a package name pattern.
 
 
 
 
 
 
 
 
 
A receiver for JavaScript AST elements that uses the Java RPC framework.
 
 
 
 
A sender for JavaScript AST elements that uses the Java RPC framework.
 
 
Validates that the contents of lists and containers like JLeftPadded respect their generic types.
 
 
 
 
 
 
 
 
 
JSX elements for JavaScript AST.
 
 
 
 
 
 
 
 
Represents a JSX tag.
 
Note: this may be used across all languages to represent a keyword as an annotation, and print without the `@`.
 
 
Contains metadata about a Node.js project, parsed from package.json and package-lock.json.
Represents a dependency request as declared in package.json.
Represents npm configuration from a specific scope.
Represents the scope/source of an npmrc configuration.
Represents the package manager used by a Node.js project.
Represents a resolved dependency from package-lock.json.
 
 
 
 
Parser for package.json files that delegates to the TypeScript PackageJsonParser via RPC.
 
 
Marker containing the resolved Prettier configuration for a source file.