Package org.openrewrite.javascript.style
Class Autodetect
java.lang.Object
org.openrewrite.style.NamedStyles
org.openrewrite.javascript.style.Autodetect
- All Implemented Interfaces:
org.openrewrite.marker.Marker,org.openrewrite.rpc.RpcCodec<Autodetect>
public class Autodetect
extends org.openrewrite.style.NamedStyles
implements org.openrewrite.rpc.RpcCodec<Autodetect>
Auto-detected styles for JavaScript/TypeScript code.
This marker is added when Prettier configuration is not available in the project. It collects formatting statistics from existing source files to detect patterns like tabs vs spaces, indent size, and brace spacing preferences.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionrpcReceive(Autodetect before, org.openrewrite.rpc.RpcReceiveQueue q) voidrpcSend(Autodetect after, org.openrewrite.rpc.RpcSendQueue q) withStyles(Collection<org.openrewrite.style.Style> styles) Methods inherited from class org.openrewrite.style.NamedStyles
canEqual, equals, getDescription, getDisplayName, getId, getName, getStyle, getStyles, getTags, hashCode, merge, merge, setDescription, setDisplayName, setId, setName, setStyles, setTags, toString, validate, withDescription, withDisplayName, withName, withTagsMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.openrewrite.marker.Marker
print
-
Constructor Details
-
Autodetect
-
-
Method Details
-
withId
- Specified by:
withIdin interfaceorg.openrewrite.marker.Marker- Overrides:
withIdin classorg.openrewrite.style.NamedStyles
-
withStyles
- Overrides:
withStylesin classorg.openrewrite.style.NamedStyles
-
rpcSend
- Specified by:
rpcSendin interfaceorg.openrewrite.rpc.RpcCodec<Autodetect>
-
rpcReceive
- Specified by:
rpcReceivein interfaceorg.openrewrite.rpc.RpcCodec<Autodetect>
-